@@ -33,15 +33,21 @@ def request(path, _retries=DEFAULT_RETRIES, _timeout=DEFAULT_TIMEOUT, **query):
             LOGGER.debug("request took more than expected - %ds", delta)
             delta = _timeout
 
+        # Raise 404 for unknown players
+        if resp.status_code == requests.codes["not_found"]:
+            resp.raise_for_status()
+
         # Rs site redirects to /unavailable with success codes on failure
         if (resp is not None and \
             resp.url == url and \
             resp.status_code == requests.codes["ok"]):
             return resp
 
+        # Ignore other server errors...
+
         # Each iteration, backoff timer grows by 2**i, but at max req roof - time taken
         time.sleep(min(2**i, _timeout-delta))
-    raise Exception("hiscore request timed out")
+    raise TimeoutError("hiscore request timed out")
 
 
 def parse_scores(text, skills):
@@ -49,15 +55,17 @@ def parse_scores(text, skills):
 
     for idx, row in enumerate(csv.reader(text.splitlines())):
         if not 2 <= len(row) <= 3:
-            LOGGER.warning("bad row in hiscores row=%s", row)
-            continue
+            raise RuntimeError(
+                "Hiscores has unexpected formatting. Update needed?"
+            ) from None
 
         try:
             rank = int(row[0])
             level = int(row[1])
         except (TypeError, ValueError):
-            LOGGER.warning("bad row in hiscores row=%s", row)
-            continue
+            raise RuntimeError(
+                "Hiscores has unexpected formatting. Update needed?"
+            ) from None
 
         # Acitivities don't have exp
         try:
@@ -68,8 +76,9 @@ def parse_scores(text, skills):
         try:
             skill = skills[idx]
         except IndexError:
-            LOGGER.debug("ignoring skill idx=%d", idx)
-            continue
+            raise RuntimeError(
+                "Hiscores has unexpected amount of entries. Update needed?"
+            ) from None
 
         if not isinstance(skill, str):
             skill = skill[0]
@@ -80,6 +89,11 @@ def parse_scores(text, skills):
             "exp": exp,
         }
 
+    if len(scores) != len(skills):
+        raise RuntimeError(
+            "Hiscores has unexpected amount of entries. Update needed?"
+        )
+
     return scores
 
 
